@@ -29,10 +29,10 @@ class Lexicon:
             韦氏拼音表 => 韦氏拼音表_标准集
             韦氏拼音表 + 非标准韦氏拼音表 => 韦氏拼音表_扩展集
         其中, 等式左侧的 "拼音表", "非标准拼音表", "韦氏拼音表", "非标准韦氏拼音
-         表" 是由人工维护和定期更新的, 等式右侧的 "拼音表_标准集", "拼音表_扩展
-         集", "韦氏拼音表_标准集", "韦氏拼音表_扩展集" 包括后面会涉及到的前缀树,
-         后缀树等衍生品, 都是由脚本根据 metadata 组合生成的 (脚本见 metadata/
-         lexicon_generator.py).
+            表" 是由人工维护和定期更新的, 等式右侧的 "拼音表_标准集", "拼音表_扩
+            展集", "韦氏拼音表_标准集", "韦氏拼音表_扩展集" 包括后面会涉及到的前
+            缀树, 后缀树等衍生品, 都是由脚本根据 metadata 组合生成的 (脚本见
+            metadata/lexicon_generator.py).
         
         下面的 self.resrc 就是脚本生成的资源文件路径字典.
         """
@@ -115,12 +115,12 @@ class PinyinCutter:
         """
         :param wade_mode: bool
         :param trie_mode: str. 'postrie'/'trie'.
-                'postrie': 反向最大匹配切词法. 例如:
-                    'yangan' -> ['yan', 'gan']
-                    'daniel' -> ['da', 'nie', 'l']
-                'trie': 正向最大匹配切词法. 例如:
-                    'yangan' -> ['yang', 'an']
-                    'daniel' -> ['dan', 'i', 'e', 'l']
+            'postrie': 反向最大匹配切词法. 例如:
+                'yangan' -> ['yan', 'gan']
+                'daniel' -> ['da', 'nie', 'l']
+            'trie': 正向最大匹配切词法. 例如:
+                'yangan' -> ['yang', 'an']
+                'daniel' -> ['dan', 'i', 'e', 'l']
         """
         self.obsv_mode = 'trie'  # obsv: observer (no usage)
         self.trie_mode = trie_mode
@@ -174,12 +174,11 @@ class PinyinCutter:
     def cut_segs_1(self, word: str) -> list:
         """ 适用于 trie_mode = 'trie'.
         
-        IO:
-            'wang' -> ['wang']
+        IO: 'wang'   -> ['wang']
             'chihau' -> ['chih', 'au']
             'xingan' -> ['xing', 'an']
             'daniel' -> ['dan', 'i', 'e', 'l']
-            'frank' -> ['f', 'ran', 'k']
+            'frank'  -> ['f', 'ran', 'k']
             'kworay' -> ['kwo', 'r', 'a', 'y']
         """
         node = self.root
@@ -212,12 +211,11 @@ class PinyinCutter:
     def cut_segs_2(self, word: str) -> list:
         """ 适用于 trie_mode = 'postrie'. 这是默认的选择.
         
-        IO:
-            'wang' -> ['wang']
+        IO: 'wang'   -> ['wang']
             'chihau' -> ['chi', 'hau']
             'xingan' -> ['xin', 'gan']
             'daniel' -> ['da', 'nie', 'l']
-            'frank' -> ['f', 'ran', 'k']
+            'frank'  -> ['f', 'ran', 'k']
             'kworay' -> ['kwo', 'r', 'a', 'y']
         """
         node = self.root
@@ -323,7 +321,7 @@ class PinyinProcessor:
     def _init_pinyin_patterns(self, wade_mode: bool):
         """ 读取中国姓氏拼音列表. """
         # self.word_pattern 该匹配式用于匹配人名中所有连续字符串, 从而剔除掉逗
-        #  号, 引号, 句点之类的干扰因素.
+        #   号, 引号, 句点之类的干扰因素.
         self.word_pattern = re.compile(r'\w+')
         
         self.pinyin_patterns = {
@@ -386,9 +384,9 @@ class PinyinProcessor:
         NOTE:
             1. name 全小写.
             2. 当传入全名时, 必须使用姓前名后且姓和名之间用英文逗号加空格分隔,
-                也就是 'lastname, firstname' 的形式. 例如 "zhang, san".
+               也就是 'lastname, firstname' 的形式. 例如 "zhang, san".
             3. 由于针对全名的判断 (e.g. "jan, edward" 和 "jan, ping xin") 并不完
-                善, 所以目前 (2019年12月3日) 不启用.
+               善, 所以目前 (2019年12月3日) 不启用.
         
         IO: da         -> True
             hu         -> True
@@ -398,9 +396,10 @@ class PinyinProcessor:
             von briton -> False
             
         :param name: 您可以传整个姓名, 也可以只传姓氏. 姓名只支持 'lastname,
-         firstname' 格式的姓名. 当传入姓名时, 判断可能会更加准确. 例如, 如果只传
-         入 "jan", 那么在 `self.wade_mode is True` 的情况下, 会判断为 True; 而传
-         入 "jan, edward" 和 "jan, ping xin", 则会分别判断为 False 和 True.
+            firstname' 格式的姓名. 当传入姓名时, 判断可能会更加准确. 例如, 如果
+            只传入 "jan", 那么在 `self.wade_mode is True` 的情况下, 会判断为
+            True; 而传入 "jan, edward" 和 "jan, ping xin", 则会分别判断为 False
+            和 True.
         """
         name = name.lower()
         
@@ -424,10 +423,10 @@ class PinyinProcessor:
         
         """
         NOTE: 原先是打算用 self.pinyin_patterns_4_name 的 pinyin 和 wade 的值来
-         判断的, 后来发现有些罕见的姓, 虽然符合拼音或韦氏拼音的构造规则, 但由于
-         不在 self.pinyin_patterns_4_name 范围内, 所以会被误判为非中国人名. 为避
-         免这种情况, 不再使用 self.pinyin_patterns_4_name 提供的 pinyin 和 wade,
-         改用 self.pinyin_patterns 的 'pinyin+wade'.
+            判断的, 后来发现有些罕见的姓, 虽然符合拼音或韦氏拼音的构造规则, 但由
+            于不在 self.pinyin_patterns_4_name 范围内, 所以会被误判为非中国人名.
+            为避免这种情况, 不再使用 self.pinyin_patterns_4_name 提供的 pinyin
+            和 wade, 改用 self.pinyin_patterns 的 'pinyin+wade'.
         """
         if self.wade_mode:
             return lastname in self.pinyin_patterns['pinyin+wade']
@@ -483,7 +482,7 @@ class PinyinProcessor:
             一般人名 (朱自清): 'zhuziqing' -> ['zhu', 'zi', 'qing']
             复姓 (欧阳修): 'ouyangxiu' -> ['ou', 'yang', 'xiu']
             歧义组合 (柴凤安): 'chaifengan' -> ['chai', 'feng', 'an'] (注: 不支
-             持切出 chai fen gan)
+                持切出 chai fen gan)
             单音节词1 (刘酬安): 'liuchouan' -> ['liu', 'chou', 'an']
             单音节词2 (刘马鄂): 'liumae' -> ['liu', 'ma', 'e']
     
@@ -491,12 +490,12 @@ class PinyinProcessor:
             对于某些歧义组合, 只支持最大向前匹配. 例如:
                 "fangan" -> ["fang", "an"]
             wade_mode 可能引发切分错误. 错误主要发生在韦氏拼音的韵母的最后一个字
-             母和下一个字的声母的首字母冲突, 例如:
+            母和下一个字的声母的首字母冲突, 例如:
                 "wang, wiehen" -> ["wang", "wieh", "en"] (切分不当)
     
         参考:
             https://blog.csdn.net/lemon_tree12138/article/details/49074809
-             #commentBox
+                #commentBox
             https://zhidao.baidu.com/question/21799136.html
         """
         return self.pinyin_cutter.main(name)
@@ -529,19 +528,18 @@ class HanzProcessor:
                                conjunction='') -> Union[str, List[str]]:
         """ 将中国人名 (中文名) 转换成拼音.
         
-        IO:
-            conjunction = ''
+        IO: conjunction = ''
                 诸葛孔明 -> 'Zhuge, Kongming'
-                刘长卿 -> 'Liu, Changqing'
+                刘长卿   -> 'Liu, Changqing'
             conjunction = ' '
                 诸葛孔明 -> 'Zhu Ge, Kong Ming'
-                刘长卿 -> 'Liu, Chang Qing'
+                刘长卿   -> 'Liu, Chang Qing'
             conjunction = '-'
                 诸葛孔明 -> 'Zhu-Ge, Kong-Ming'
-                刘长卿 -> 'Liu, Chang-Qing'
+                刘长卿   -> 'Liu, Chang-Qing'
             conjunction = 'list'
                 诸葛孔明 -> ['zhu', 'ge', 'kong', 'ming']
-                刘长卿 -> ['liu', 'chang', 'qing']
+                刘长卿   -> ['liu', 'chang', 'qing']
             ...
         
         本函数特点:
@@ -579,7 +577,7 @@ class HanzProcessor:
         """ 将百家姓中的多音字转换为同音的非多音字.
         
         百家姓里的多音字: https://zhidao.baidu.com/question/188597315.html?qbl=
-         relate_question_0&word=%B0%D9%BC%D2%D0%D5%20%B6%E0%D2%F4%D7%D6
+            relate_question_0&word=%B0%D9%BC%D2%D0%D5%20%B6%E0%D2%F4%D7%D6
         
         注意:
             1. "汤" -> "商" 变换未认证, 所以没收录
