@@ -2,23 +2,22 @@
 @Author  : Likianta <likianta@foxmail.com>
 @Module  : excel_writer.py
 @Created : 2018-00-00
-@Updated : 2020-08-21
-@Version : 2.2.8
+@Updated : 2020-09-06
+@Version : 2.3.2
 @Desc    : ExcelWriter is a post-packing implementation based on XlsxWriter.
 """
 from os import path as ospath
 from typing import *
 from warnings import filterwarnings
 
-from .lk_logger import lk
-
 # shield Python 3.8 SyntaxWarning from XlsxWriter.
 filterwarnings('ignore', category=SyntaxWarning)
 
 
 class ExcelWriter:
     """ ExcelWriter is an encapsulated implementation of xlsxwriter module,
-    designed to provide more flexible and ease of use excel writing experience.
+        designed to provide more flexible and ease of use excel writing
+        experience.
     
     Refer: https://www.jianshu.com/p/187e6b86e1d9
     Palette: `xlsxwriter.format.Format._get_color`
@@ -28,7 +27,7 @@ class ExcelWriter:
     _merge_format: ...
     book: ...
     filepath: str
-    rowx: int
+    rowx: int  # auto increasing row index, see self.writeln, self.writelnx.
     sheet: ...
     sheetx: int
     
@@ -49,18 +48,16 @@ class ExcelWriter:
         self.sheetx = 0
         self.rowx = -1
         
-        if filepath.endswith('.xls'):
-            lk.logt('[ExcelWriter][I2504]',
-                    'ExcelWriter doesn\'t support xls format, will use xlsx '
-                    'instead.', filepath, h='parent')
-            filepath += 'x'
+        if not filepath.endswith('.xlsx'):
+            raise ValueError('ExcelWriter only supports .xlsx file type.',
+                             filepath)
         self.filepath = filepath
         
         # create workbook
         import xlsxwriter
         self.book = xlsxwriter.Workbook(
             filename=filepath,
-            options=options or {  # the default options
+            options={  # the default options
                 'strings_to_numbers'       : True,
                 'strings_to_urls'          : False,
                 'constant_memory'          : False,
@@ -73,6 +70,7 @@ class ExcelWriter:
                     # 'valign': 'vcenter',  # cell's vertical alignment
                     # 'text_wrap': False,  # auto line wrap (default False)
                 },
+                **options
             }
         )
         
@@ -100,6 +98,7 @@ class ExcelWriter:
         self.__h = 'parent'  # reset
     
     def save(self):
+        from lk_logger import lk
         lk.logt('[ExcelWriter][I1139]', f'Excel saved to "{self.filepath}"',
                 h=self.__h)
         self.book.close()
@@ -123,13 +122,16 @@ class ExcelWriter:
         """ Write line of data to cells (with auto line breaks). """
         if purify_values:
             row = self.purify_values(row)
-        index = self._increase_rowx()
+        self.rowx += 1
         if self.rowx == 0 or not auto_index:
             self.sheet.write_row(self.rowx, 0, row, fmt)
         else:
-            self.sheet.write(self.rowx, 0, index, fmt)
+            self.sheet.write(self.rowx, 0, self.rowx, fmt)
             self.sheet.write_row(self.rowx, 1, row, fmt)
     
+    def writelnx(self, *row, fmt=None):
+        self.writeln(*row, auto_index=True, fmt=fmt)
+    
     def writerow(self, rowx, data, offset=0, purify_values=False, fmt=None):
         """ Write row of data to cells. """
         if purify_values:
@@ -142,10 +144,6 @@ class ExcelWriter:
             data = self.purify_values(data)
         self.sheet.write_column(offset, colx, data, fmt)
     
-    def _increase_rowx(self):
-        self.rowx += 1
-        return self.rowx
-    
     @staticmethod
     def purify_values(row):
         """
@@ -254,6 +252,7 @@ class ExcelWriter:
         if not sheet_name:
             sheet_name = f'sheet {self.sheetx}'  # -> 'sheet 1', 'sheet 2', ...
         if prompt:
+            from lk_logger import lk
             lk.logt('[ExcelWriter][D1344]',
                     f'Add new sheet: "{sheet_name}" (sheetx {self.sheetx})',
                     ospath.split(self.filepath)[1])
