@@ -2,8 +2,8 @@
 @Author  : Likianta <likianta@foxmail.com>
 @Module  : filesniff.py
 @Created : 2018-00-00
-@Updated : 2020-08-21
-@Version : 1.6.3
+@Updated : 2020-09-06
+@Version : 1.8.2
 @Desc    : Get filepath in elegant way.
     Note: in this module getters' behaviors are somewhat different from
     `os.path` or `pathlib`, see below:
@@ -24,6 +24,69 @@ import sys
 from typing import *
 
 
+class FSPath(str):  # TODO: 暂未投入使用.
+    """ FSPath 是在 str 类型的路径的基础上, 附加了一些简便的路径操作. 您可以将它
+        完全当作普通的字符串使用. """
+    
+    _path: str
+    path_type: str  # 'filepath' or 'dirpath'.
+    
+    # file related
+    filepath = ''
+    filename = ''
+    stem = ''
+    ext = ''  # extension
+    suffix = ''  # the same to `ext`
+    
+    # directory related
+    dirpath = ''
+    dirname = ''
+    
+    def __init__(self, path: str, path_type=''):
+        super().__init__()
+        self._path = path
+        self.path_type = path_type or 'filepath' if isfile(path) else 'dirpath'
+        
+        if self.path_type == 'filepath':
+            self.filepath = path
+            self.filename = get_filename(path)
+            self.stem, self.ext = self.filename.rsplit('.', 1)
+            self.suffix = self.ext
+        else:
+            self.dirpath = path
+            self.dirname = get_dirname(path)
+    
+    @property
+    def isfile(self) -> bool:
+        return self.path_type == 'filepath'
+    
+    @property
+    def isdir(self) -> bool:
+        return self.path_type == 'dirpath'
+    
+    @property
+    def exists(self) -> bool:
+        return os.path.exists(self._path)
+    
+    is_exists = exists
+    
+    # 重载 `/` 运算符.
+    # https://blog.csdn.net/zhangshuaijun123/article/details/82149056
+    def __truediv__(self, node: str):
+        return FSPath(self._path + '/' + node)
+    
+    def force_create_path(self):
+        path_nodes = self.dirpath.split('/')
+        dirpath = path_nodes[0]
+        cnt = 0  # 计数创建了多少层目录.
+        for node in path_nodes[1:]:
+            dirpath += '/' + node
+            if not os.path.exists(dirpath):
+                cnt += 1
+                os.mkdir(dirpath)
+        return cnt
+
+
 # ------------------------------------------------------------------------------
 # Prettifiers
 
@@ -42,10 +105,14 @@ def get_dirname(path: str) -> str:
     """ Input a dirpath or filepath, return the dirname.
     *We don't check the dirpath exists or not.*
     """
-    if isdir(path):
+    if os.path.exists(path):
+        return os.path.dirname(path)
+    elif isdir(path):
         return path.rsplit('/', 1)[-1]
     else:
-        if path.count('/') == 1:
+        if path.count('/') == 0:
+            raise Exception('Cannot resolve dirname from this path', path)
+        elif path.count('/') == 1:
             return path.split('/', 1)[0]
         else:
             return path.rsplit('/', 2)[-2]
@@ -110,13 +177,13 @@ PRJDIR = __get_prj_dir()  # project's dirpath
 
 def stitch_path(*path_nodes, wrapper=None):
     """
-    Use case:
+    Usecase:
         class FileReader:
             def __init__(self, path):
                 self.holder = open(path, 'r')
                 
         reader = stitch_path('D:', 'myprj', 'model', 'sample.txt', FileReader)
-        # equals to: `reader = FileReader('D:/myprj/model/sample.txt')`
+        #   equals to: `reader = FileReader('D:/myprj/model/sample.txt')`
         
     :param path_nodes:
     :param wrapper:
@@ -155,53 +222,33 @@ def lkdb(*subpath):
 # Path Finders (File Finders)
 
 def _find_paths(adir: str, path_type: str, fmt: str,
-                suffix: Union[str, List, Tuple] = '', recursive=False,
+                suffix: Union[str, Tuple] = '', recursive=False,
                 custom_filter=None):
-    """ Base find method.
+    """ Basic find.
     
     :param adir: target path to find in.
     :param path_type: 'file'/'dir'.
-    :param fmt: 'filepath'/'filename'/'zip'/'dict'/'dlist'.
-        'filepath': return absolute filepaths.
-            e.g. ['D:/A/B.txt', 'D:/A/C.txt', ...]
-        'filename': return filenames only.
-            e.g. ['B.txt', 'C.txt', ...]
-        'zip': return zip(filenames, filepaths).
-            e.g. zip(['B.txt', 'C.txt', ...], ['D:/A/B.txt', 'D:/A/C.txt', ...])
-        'dict': return {filename: filepath}.
-            e.g. {'B.txt': 'D:/A/B.txt', 'C.txt': 'D:/A/C.txt', ...}
-        'dlist': return (filenames, filepaths).
-            e.g. (['B.txt', 'C.txt', ...], ['D:/A/B.txt', 'D:/A/C.txt', ...])
+    :param fmt: decides the which structure of data returned. options below:
+        'filepath'/'dirpath'/'path'
+        'filename'/'dirname'/'name'
+        'zip'
+        'dict'
+        'dlist'/'list'
     :param suffix: assign a filter to which file types we want to fetch.
-        For example, we want only .txt files in target folder, then code like:
-            _find_paths(target_folder, path_type='file', fmt='abspath',
-                        suffix='.txt')
-        Or we want .xlsx and .xlsm files:
-            _find_paths(target_folder, path_type='file', fmt='abspath',
-                        suffix=('.xlsx', '.xlsm'))
         NOTICE:
             1. Each suffix name must start with a dot ('.jpg', '.txt', etc.).
-            2. The default schema of str-type is very casual! It means if we
-               want .htm and .html files, just code:
-                    _find_paths(target_folder, path_type='file', fmt='abspath',
-                                suffix='.htm')
-               It returns both .htm, .html and even anything matched `.htm*`!
-               If it not as your expect, pls use list/tuple to constraint:
-                    _find_paths(target_folder, path_type='file', fmt='abspath',
-                                suffix=['.htm'])  # will only return .htm
-            3. Not case sensitive.
-        TLDR:
-            - Use `suffix='.txt'` if you want to fetch .txt files by fuzzy
-              match.
-            - Use `suffix=['.txt', ...]` if you want to fetch multi-type files
-              and by exact match.
+            2. Case sensitive.
+            3. Param type is str or tuple, cannot be list.
     :param recursive: whether to find descendant folders.
-        NOTICE: be careful if you set `fmt='dict'` & `recursive=True`, it is
-        unsafe that some files with the same names will be overritten.
     :param custom_filter: if you want a more powerful filter than `suffix`
-     param, set it here. The `custom_filter` works after `suffix` filter.
-     Use case: see `find_subdirs()`, `findall_subdirs()`.
+        param, set it here. The `custom_filter` works after `suffix` filter.
+        Usecase: see `find_subdirs()`, `findall_subdirs()`.
     :return:
+        fmt = 'filepath'/'dirpath'/'path' -> return [filepath, ...]
+        fmt = 'filename'/'dirname'/'name' -> return [filename, ...]
+        fmt = 'zip' -> return zip([filepath, ...], [filename, ...])
+        fmt = 'dict' -> return {filepath: filename, ...}
+        fmt = 'dlist'/'list' -> return [filepath, ...], [filename, ...]
     """
     adir = prettify_dir(adir)
     
@@ -209,11 +256,11 @@ def _find_paths(adir: str, path_type: str, fmt: str,
     if recursive is False:
         names = os.listdir(adir)
         paths = (f'{adir}/{f}' for f in names)
-        mix = zip(names, paths)
+        out = zip(paths, names)
         if path_type == 'file':
-            mix = filter(lambda x: os.path.isfile(x[1]), mix)
+            out = filter(lambda x: os.path.isfile(x[0]), out)
         else:
-            mix = filter(lambda x: os.path.isdir(x[1]), mix)
+            out = filter(lambda x: os.path.isdir(x[0]), out)
     else:
         names = []
         paths = []
@@ -225,34 +272,27 @@ def _find_paths(adir: str, path_type: str, fmt: str,
             else:
                 names.extend(dirnames)
                 paths.extend((f'{root}/{d}' for d in dirnames))
-        mix = zip(names, paths)
+        out = zip(paths, names)
     
     # suffix
     if suffix:
-        if isinstance(suffix, str):
-            mix = filter(lambda x: suffix in x[0], mix)  # fuzzy filter suffix
-        elif isinstance(suffix, (tuple, list)):
-            mix = filter(
-                lambda x: '.' + x[0].rsplit('.', 1)[-1].lower() in suffix, mix
-            )
-        else:
-            raise ValueError('Unknown suffix type', suffix, type(suffix))
+        out = filter(lambda x: x[1].endswith(suffix), out)
     
     # custom_filter
     if custom_filter:
-        mix = filter(custom_filter, mix)
+        out = filter(custom_filter, out)
     
     # fmt
     if fmt in ('filepath', 'dirpath', 'path'):
-        return [y for x, y in mix]
+        return [fp for fp, fn in out]
     elif fmt in ('filename', 'dirname', 'name'):
-        return [x for x, y in mix]
+        return [fn for fp, fn in out]
     elif fmt == 'zip':
-        return mix
+        return out
     elif fmt == 'dict':
-        return dict(mix)
+        return dict(out)
     elif fmt in ('dlist', 'list'):
-        return zip(*mix)
+        return zip(*out)
     else:
         raise ValueError('Unknown fmt', fmt)
 
@@ -277,7 +317,7 @@ def find_subdirs(adir, fmt='dirpath', suffix='',
     :param fmt:
     :param suffix:
     :param exclude_protected_folder: exclude folders which startswith "." or
-     "__" (e.g. ".git", ".idea", "__pycache__", etc.).
+        "__" (e.g. ".git", ".idea", "__pycache__", etc.).
     :return:
     """
     
@@ -314,9 +354,8 @@ findall_dirs = findall_subdirs  # alias
 
 def isfile(filepath: str) -> bool:
     """ Unsafe method judging path-like string.
-    TLDR:
-        If `filepath` looks like a filepath, will return True; otherwise return
-         False.
+    TLDR: If `filepath` looks like a filepath, will return True; otherwise
+        return False.
     Judgement based:
         - Does it end with '/'? -> False
         - Does it really exist on system? -> True
@@ -343,9 +382,8 @@ def isfile(filepath: str) -> bool:
 
 def isdir(dirpath: str) -> bool:
     """ Unsafe method judging dirpath-like string.
-    TLDR:
-        If `dirpath` looks like a dirpath, will return True; otherwise return
-         False.
+    TLDR: If `dirpath` looks like a dirpath, will return True; otherwise return
+        False.
     Judgement based:
         - Is it a dot/dot-slash/slash? -> True
         - Does it really exist on system? -> True
@@ -385,7 +423,7 @@ def _calc_path(base: str, offset: str):
 
 def path_on_prj(offset: str):
     """ Calculate path based on PRJDIR as pivot.
-    e.g. PRJDIR = 'D:/myprj', path = 'src/main.py' -> 'D:/myprj/src/main.py'
+    E.g. PRJDIR = 'D:/myprj', path = 'src/main.py' -> 'D:/myprj/src/main.py'
     """
     return _calc_path(PRJDIR, offset)
 
@@ -423,8 +461,8 @@ def dialog(adir, suffix, prompt='请选择您所需文件的对应序号') -> st
     """ File select dialog (Chinese). """
     print(f'当前目录为: {adir}')
     
-    # fn: filenames, fp: filepaths
-    fn, fp = find_files(adir, suffix, 'list')
+    # fp: filepaths, fn: filenames
+    fp, fn = find_files(adir, suffix, 'list')
     
     if not fn:
         raise FileNotFoundError(f'当前目录没有找到目标类型 ({suffix}) 的文件')
@@ -444,7 +482,7 @@ def dialog(adir, suffix, prompt='请选择您所需文件的对应序号') -> st
         return fp[int(index)]
 
 
-def create_dirpath(path: str):
+def force_create_dirpath(path: str):
     dirpath = (nodes := path.split('/'))[0]
     for node in nodes[1:]:
         dirpath += '/' + node
